# -*- coding: UTF-8 -*-
__author__ = "helios"
__doc__ = "Run"
"""
  * @File    :   Run.py
  * @Time    :   2023/04/25 23:07:53
  * @Author  :   helios
  * @Version :   1.0
  * @Contact :   yuyang.0515@qq.com
  * @License :   (C)Copyright 2019-2023, Ship of Ocean
  * @Desc    :   None
"""


class Run:
    pass
